json

package
v0.0.0-...-8a59038 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 25, 2020 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Decode

func Decode(reader io.Reader, stream chan<- *proto.Payload) error

Decode JSON input from io.Reader sending entities one by one to the stream channel.

func Encode

func Encode(writer io.Writer, stream <-chan *proto.Payload) error

Encode entities from the stream channel writing to the provided io.Writer.

Types

This section is empty.

Jump to